@@ -19,9 +19,10 @@
 #include "calendaringtest.h"
 
 #include <QTest>
+#include <ksystemtimezone.h>
 #include <kolabevent.h>
 #include <iostream>
-#include "calendaring/calendaring.h"
+#include <calendaring/calendaring.h>
 #include <calendaring/event.h>
 #include <calendaring/datetimeutils.h>
 
@@ -41,6 +42,11 @@ void compareEvents(const std::vector<Kolab::Event> &list1, const std::vector<Kol
     }
 }
 
+void CalendaringTest::initTestCase()
+{
+    QVERIFY2(KSystemTimeZones::isTimeZoneDaemonAvailable(), "Timezone support is required for this test. Either use libcalendaring or make sure KTimeZoned is available");
+}
+
 void CalendaringTest::testCalendaringEvent()
 {
     Kolab::Event event;
